aboutsummaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
-rw-r--r--core/Command/App/Remove.php4
1 files changed, 2 insertions, 2 deletions
diff --git a/core/Command/App/Remove.php b/core/Command/App/Remove.php
index ee60fcc0827..2ea10930427 100644
--- a/core/Command/App/Remove.php
+++ b/core/Command/App/Remove.php
@@ -49,9 +49,9 @@ class Remove extends Command implements CompletionAwareInterface {
protected function execute(InputInterface $input, OutputInterface $output): int {
$appId = $input->getArgument('app-id');
// Check if the app is installed
if (!$this->manager->isInstalled($appId)) {
- $output->writeln($appId . ' is not installed');
+ $output->writeln($appId . ' is not enabled');
return 1;
}
@@ -49,9 +49,9 @@ class Remove extends Command implements CompletionAwareInterface {
protected function execute(InputInterface $input, OutputInterface $output): int {
$appId = $input->getArgument('app-id');
- // Check if the app is installed
+ // Check if the app is enabled
if (!$this->manager->isInstalled($appId)) {